==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/fr.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Il y a eu un problème lors de la lecture des fichiers de cet album",
    "Aborting preview. Could not find the file" : "Interruption de la prévisualisation. Le fichier est introuvable.",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "No compatible server found at {remote}" : "Aucun serveur compatible trouvé sur {remote}",
    "Invalid server url" : "Url serveur invalide",
    "Gallery view" : "Vue en galerie",
    "Could not load the description" : "Impossible de charger la description",
    "Could not load the description: " : "Impossible de charger la description :",
    "Copyright" : "Droit d'auteur",
    "Could not load the copyright notice: " : "Impossible de charger l'avis de droit d'auteur :",
    "Copyright notice" : "Avis de droit d'auteur",
    "Link to copyright document" : "Lien vers l'avis de droit d'auteur complet",
    "This application may not work properly on your browser." : "Cette application pourrait ne pas fonctionner correctement dans votre navigateur.",
    "For an improved experience, please install one of the following alternatives" : "Pour une meilleure expérience, veuillez installer l'une des alternatives suivantes",
    "Your browser is not supported!" : "Votre navigateur n'est pas pris en charge !",
    "please install one of the following alternatives" : "veuillez installer l'une des alternatives suivantes",
    "Album cannot be shown" : "L'album ne peut être affiché",
    "No media files found" : "Aucun fichier média trouvé",
    "Upload pictures in the files app to display them here" : "Ajoutez des images dans l'application Fichiers et elles apparaîtront ici",
    "Upload new files via drag and drop or by using the [+] button above" : "Téléversez de nouveaux fichiers en utilisant le glisser-déposer ou le bouton [+] ci-dessus",
    "Configuration error" : "Erreur de configuration",
    "New" : "Nouveau",
    "Hide Album" : "Masquer l'album",
    "Could not hide album" : "Impossible de masquer l'album",
    "Error loading slideshow template" : "Erreur lors du téléchargement du modèle de diaporama ",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erreur !</strong> Impossible de générer un aperçu de ce fichier.<br>Merci d'aller à la diapositive suivante pendant que nous supprimons cette image de ce diaporama",
    "Next" : "Suivant",
    "Play" : "Démarrer",
    "Pause" : "Pause",
    "Previous" : "Précédent",
    "Close" : "Fermer",
    "Download" : "Télécharger",
    "Toggle background" : "Activer/Désactiver l'arrière-plan",
    "Delete" : "Supprimer",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Upload" : "Téléverser",
    "Error" : "Erreur",
    "Error while sharing" : "Erreur lors de la mise en partage",
    "Error while unsharing" : "Erreur lors de l'annulation du partage",
    "Error while changing permissions" : "Erreur lors du changement des permissions",
    "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
    "Shared with you by {owner}" : "Partagé avec vous par {owner}",
    "Share with users or groups …" : "Partager avec des utilisateurs ou groupes...",
    "Share with users, groups or remote users …" : "Partager avec des utilisateurs, groupes, ou utilisateurs distants",
    "Share" : "Partager",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Partager avec des personnes sur d'autres serveurs en utilisant leur identifiant du Cloud Fédéré utilisateur@exemple.com/cloud",
    "Share link" : "Partage par lien",
    "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
    "Link" : "Lien",
    "Password protect" : "Protéger par un mot de passe",
    "Password" : "Mot de passe",
    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
    "Allow editing" : "Permettre la modification",
    "Email link to person" : "Envoyer le lien par courriel",
    "Send" : "Envoyer",
    "Set expiration date" : "Spécifier une date d'expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Date d'expiration",
    "An error occured. Please try again" : "Une erreur est survenue. Merci de réessayer",
    "Adding user..." : "Ajout de l'utilisateur...",
    "group" : "groupe",
    "remote" : "distant",
    "Resharing is not allowed" : "Le repartage n'est pas autorisé",
    "Error while retrieving shares" : "Erreur lors de la récupération des partages",
    "Unshare" : "Ne plus partager",
    "notify by email" : "notifier par courriel",
    "can share" : "peut partager",
    "can edit" : "peut modifier",
    "access control" : "contrôle d'accès",
    "create" : "création",
    "change" : "modification",
    "delete" : "suppression",
    "Password protected" : "Protégé par mot de passe",
    "Error unsetting expiration date" : "Erreur lors de la suppression de la date d'expiration",
    "Error setting expiration date" : "Erreur lors de la spécification de la date d'expiration",
    "Sending ..." : "Envoi…",
    "Email sent" : "E-mail envoyé",
    "Warning" : "Attention",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Sort by date" : "Trier par date",
    "Sort by name" : "Trier par nom",
    "Cancel upload" : "Annuler le téléversement",
    "Album information" : "Informations sur l'album",
    "File list" : "Liste des fichiers",
    "Sorry, this file could not be found." : "Désolé, ce fichier n'a pas pu être trouvé.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the wrong file ID was provided" : "l'identifiant de fichier spécifié est incorrect",
    "the file was removed" : "le fichier a été supprimé",
    "the file is corrupt" : "le fichier est corrompu",
    "the encryption key is missing" : "la clé de chiffrement est manquante",
    "Here is the error message returned by the server: " : "Message d'erreur renvoyé par le serveur :",
    "For more information, please contact your friendly Nextcloud administrator." : "Pour plus d'informations, veuillez contacter votre administrateur Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Désolé, le serveur ne peut satisfaire votre requête.",
    "Possible reasons for the problem:" : "Raisons possibles du problème :",
    "a conflicting app was installed" : "une application incompatible a été installée",
    "a required component is missing or was disconnected" : "un composant requis est manquant ou a été déconnecté",
    "the filesystem is not readable" : "le système de fichiers n'est pas lisible",
    "For more information, please contact your friendly ownCloud administrator." : "Pour plus d'informations, veuillez contacter votre administrateur ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Désolé, ce lien semble ne plus fonctionner.",
    "the item was removed" : "l'élément a été supprimé",
    "the link has expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more information, please ask the person who has sent you this link." : "Pour plus d'informations, veuillez contacter la personne qui vous a envoyé ce lien.",
    "Add to your Nextcloud" : "Ajouter à votre Nextcloud",
    "Picture view" : "Visualisation de l'image"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/fr.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Il y a eu un problème lors de la lecture des fichiers de cet album",
    "Aborting preview. Could not find the file" : "Interruption de la prévisualisation. Le fichier est introuvable.",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "No compatible server found at {remote}" : "Aucun serveur compatible trouvé sur {remote}",
    "Invalid server url" : "Url serveur invalide",
    "Gallery view" : "Vue galerie",
    "Could not load the description" : "Impossible de charger la description",
    "Could not load the description: " : "Impossible de charger la description :",
    "Copyright" : "Droit d'auteur",
    "Could not load the copyright notice: " : "Impossible de charger l'avis de droit d'auteur :",
    "Copyright notice" : "Avis de droit d'auteur",
    "Link to copyright document" : "Lien vers l'avis de droit d'auteur complet",
    "This application may not work properly on your browser." : "Cette application pourrait ne pas fonctionner correctement dans votre navigateur.",
    "For an improved experience, please install one of the following alternatives" : "Pour une meilleure expérience, veuillez installer l'une des alternatives suivantes",
    "Your browser is not supported!" : "Votre navigateur n'est pas pris en charge !",
    "please install one of the following alternatives" : "veuillez installer l'une des alternatives suivantes",
    "Album cannot be shown" : "L'album ne peut être affiché",
    "No media files found" : "Aucun fichier média trouvé",
    "Upload pictures in the files app to display them here" : "Ajoutez des images dans l'application Fichiers et elles apparaîtront ici",
    "Upload new files via drag and drop or by using the [+] button above" : "Téléversez de nouveaux fichiers en utilisant le glisser-déposer ou le bouton [+] ci-dessus",
    "Configuration error" : "Erreur de configuration",
    "New" : "Nouveau",
    "Hide Album" : "Masquer l'album",
    "Could not hide album" : "Impossible de masquer l'album",
    "Error loading slideshow template" : "Erreur lors du téléchargement du modèle de diaporama ",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erreur !</strong> Impossible de générer un aperçu de ce fichier.<br>Merci d'aller à la diapositive suivante pendant que nous supprimons cette image de ce diaporama",
    "Next" : "Suivant",
    "Play" : "Démarrer",
    "Pause" : "Pause",
    "Previous" : "Précédent",
    "Close" : "Fermer",
    "Download" : "Télécharger",
    "Toggle background" : "Activer/Désactiver l'arrière-plan",
    "Delete" : "Supprimer",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Upload" : "Téléverser",
    "Error" : "Erreur",
    "Error while sharing" : "Erreur lors de la mise en partage",
    "Error while unsharing" : "Erreur lors de l'annulation du partage",
    "Error while changing permissions" : "Erreur lors du changement des permissions",
    "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
    "Shared with you by {owner}" : "Partagé avec vous par {owner}",
    "Share with users or groups …" : "Partager avec des utilisateurs ou groupes...",
    "Share with users, groups or remote users …" : "Partager avec des utilisateurs, groupes, ou utilisateurs distants",
    "Share" : "Partager",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Partager avec des personnes sur d'autres serveurs en utilisant leur identifiant du Cloud Fédéré utilisateur@exemple.com/cloud",
    "Share link" : "Partage par lien",
    "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
    "Link" : "Lien",
    "Password protect" : "Protéger par un mot de passe",
    "Password" : "Mot de passe",
    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
    "Allow editing" : "Permettre la modification",
    "Email link to person" : "Envoyer le lien par courriel",
    "Send" : "Envoyer",
    "Set expiration date" : "Indiquer une date d'expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Date d'expiration",
    "This list is maybe truncated - please refine your search term to see more results." : "Des résultats peuvent avoir été omis. Affinez votre recherche pour en voir plus.",
    "No users or groups found for {search}" : "Aucun utilisateur ou groupe trouvé pour {search}",
    "No users found for {search}" : "Aucun utilisateur trouvé pour {search}",
    "An error occured. Please try again" : "Une erreur est survenue. Merci de réessayer",
    "Adding user..." : "Ajout de l'utilisateur...",
    "group" : "groupe",
    "remote" : "distant",
    "Resharing is not allowed" : "Le repartage n'est pas autorisé",
    "Error while retrieving shares" : "Erreur lors de la récupération des partages",
    "Unshare" : "Ne plus partager",
    "notify by email" : "notifier par courriel",
    "can share" : "peut partager",
    "can edit" : "peut modifier",
    "access control" : "contrôle d'accès",
    "create" : "création",
    "change" : "modification",
    "delete" : "suppression",
    "Password protected" : "Protégé par mot de passe",
    "Error unsetting expiration date" : "Erreur lors de la suppression de la date d'expiration",
    "Error setting expiration date" : "Erreur lors de la spécification de la date d'expiration",
    "Sending ..." : "Envoi…",
    "Email sent" : "E-mail envoyé",
    "Warning" : "Attention",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Sort by date" : "Trier par date",
    "Sort by name" : "Trier par nom",
    "Cancel upload" : "Annuler le téléversement",
    "Album information" : "Informations sur l'album",
    "File list" : "Liste des fichiers",
    "Sorry, this file could not be found." : "Désolé, ce fichier n'a pas pu être trouvé.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the wrong file ID was provided" : "l'identifiant de fichier spécifié est incorrect",
    "the file was removed" : "le fichier a été supprimé",
    "the file is corrupt" : "le fichier est corrompu",
    "the encryption key is missing" : "la clé de chiffrement est manquante",
    "Here is the error message returned by the server: " : "Message d'erreur renvoyé par le serveur :",
    "For more information, please contact your friendly Nextcloud administrator." : "Pour plus d'informations, veuillez contacter votre administrateur Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Désolé, le serveur ne peut satisfaire votre requête.",
    "Possible reasons for the problem:" : "Raisons possibles du problème :",
    "a conflicting app was installed" : "une application incompatible a été installée",
    "a required component is missing or was disconnected" : "un composant requis est manquant ou a été déconnecté",
    "the filesystem is not readable" : "le système de fichiers n'est pas lisible",
    "For more information, please contact your friendly ownCloud administrator." : "Pour plus d'informations, veuillez contacter votre administrateur ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Désolé, ce lien semble ne plus fonctionner.",
    "the item was removed" : "l'élément a été supprimé",
    "the link has expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more information, please ask the person who has sent you this link." : "Pour plus d'informations, veuillez contacter la personne qui vous a envoyé ce lien.",
    "Add to your Nextcloud" : "Ajouter à votre Nextcloud",
    "Picture view" : "Visualisation de l'image"
},
"nplurals=2; plural=(n > 1);");
